@@ -230,8 +230,7 @@ fn description() {
     }
 
     let meta = get_meta::<Obj>();
-    assert_eq!(meta.title, Some("A"));
-    assert_eq!(meta.description, Some("AB\nCDE"));
+    assert_eq!(meta.description, Some("A\n\nAB\nCDE"));
 }
 
 #[test]
@@ -247,8 +246,7 @@ fn field_description() {
 
     let meta = get_meta::<Obj>();
     let field_meta = meta.properties[0].1.unwrap_inline();
-    assert_eq!(field_meta.title, Some("A"));
-    assert_eq!(field_meta.description, Some("AB\nCDE"));
+    assert_eq!(field_meta.description, Some("A\n\nAB\nCDE"));
 }
 
 #[test]
@@ -464,7 +462,7 @@ fn inline_fields() {
     assert_eq!(
         meta_inner_obj.all_of[1],
         MetaSchemaRef::Inline(Box::new(MetaSchema {
-            title: Some("Inner Obj"),
+            description: Some("Inner Obj"),
             default: Some(serde_json::json!({
                 "v": 100,
             })),
@@ -480,7 +478,7 @@ fn inline_fields() {
     assert_eq!(
         meta_inner_enum.all_of[1],
         MetaSchemaRef::Inline(Box::new(MetaSchema {
-            title: Some("Inner Enum"),
+            description: Some("Inner Enum"),
             default: Some(serde_json::json!("B")),
             ..MetaSchema::ANY
         }))
@@ -693,3 +691,37 @@ fn issue_171() {
 
     let _ = poem_openapi::OpenApiService::new(Api, "a", "1.0");
 }
+
+#[test]
+fn flatten_field() {
+    #[derive(Object, Debug, Eq, PartialEq)]
+    struct Obj1 {
+        a: i32,
+        b: i32,
+    }
+
+    #[derive(Object, Debug, Eq, PartialEq)]
+    struct Obj {
+        #[oai(flatten)]
+        obj1: Obj1,
+        c: i32,
+    }
+
+    let meta = get_meta::<Obj>();
+    assert_eq!(meta.required, vec!["a", "b", "c"]);
+
+    assert_eq!(meta.properties[0].0, "a");
+    assert_eq!(meta.properties[1].0, "b");
+    assert_eq!(meta.properties[2].0, "c");
+
+    let obj = Obj {
+        obj1: Obj1 { a: 100, b: 200 },
+        c: 300,
+    };
+
+    assert_eq!(obj.to_json(), json!({"a": 100, "b": 200, "c": 300}));
+    assert_eq!(
+        Obj::parse_from_json(json!({"a": 100, "b": 200, "c": 300})).unwrap(),
+        obj
+    );
+}
